:orphan:

Meet Sphinxit!
==============

.. warning::
    Sphinxit documentation is not full yet. I promise to make it more detailed soon.

Hello and welcome to the **Sphinxit** documentation. This documentation is divided into
different parts. I recommend that you get started with :ref:`installation`
and then head over to the :ref:`quickstart`.

**Sphinxit** is light and powerful **SphinxQL** query constructor. More, it is the set of helpers
to make search with `Sphinx <http://sphinxsearch.com/>`_ easy to use in any kind of Python projects 
like Django, Flask and others. Sphinxit is independent Python library and you are free to use it 
anywhere you need powerful Sphinx-based search. 

Make full-text queries, filtering, ordering, grouping and aggregations.
Forget about deprecated Sphinx API or unpredictable non-tested batteries. Sphinxit is just better.

Sphinxit documentation doesn`t cover whole Sphinx possibilities and if you are not familiar with 
SphinxSearch engine or you need some kind of Sphinx-specific documentation, visit it`s 
`official website <http://sphinxsearch.com/docs/current.html>`_.

.. include:: contents.rst.inc
